@echo off
REM Change directory to the folder containing this script
REM This ensures that all subsequent commands are run from the same location as the script
cd /d %~dp0

REM Create a local directory for Spark configuration if it doesn't already exist
mkdir local-spark-conf

REM Build the Docker image using the Dockerfile in the current directory
REM The image will be tagged as 'bitnami-spark-single-node'
docker build -t bitnami-spark-single-node .

REM Run the Docker container in detached mode
REM - Connect it to the 'dasnet' Docker network so it can interact with other services
REM - Assign the container the name 'bitnami-spark-single-node'
REM - Expose necessary ports for Spark Web UI and master-worker communication
REM - Map the local 'local-spark-conf' directory to '/opt/spark/conf' inside the container for configuration files
docker run -d --network dasnet --name bitnami-spark-single-node -p 4040:4040 -p 8080:8080 -p 7077:7077 -v %cd%\local-spark-conf:/opt/spark/conf bitnami-spark-single-node

REM Check if the container is running and print a success message if it is
docker ps | findstr "bitnami-spark-single-node" >nul
if %errorlevel%==0 (
    echo Setup was successful! The bitnami-spark-single-node container is running.
) else (
    echo Setup failed! The bitnami-spark-single-node container is not running.
)

REM Keep the window open so that the user can review the output
pause
